@@ -5,6 +5,88 @@
 
 #include "ev-document-type-builtins.h"
 
+/* enumerations from "ev-annotation.h" */
+#include "ev-annotation.h"
+GType
+ev_annotation_type_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+ 
+  if (g_once_init_enter (&g_define_type_id__volatile)) {
+    static const GEnumValue values[] = {
+      { EV_ANNOTATION_TYPE_UNKNOWN, "EV_ANNOTATION_TYPE_UNKNOWN", "unknown" },
+      { EV_ANNOTATION_TYPE_TEXT, "EV_ANNOTATION_TYPE_TEXT", "text" },
+      { EV_ANNOTATION_TYPE_ATTACHMENT, "EV_ANNOTATION_TYPE_ATTACHMENT", "attachment" },
+      { 0, NULL, NULL }
+    };
+    GType g_define_type_id = \
+       g_enum_register_static (g_intern_static_string ("EvAnnotationType"), values);
+      
+    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+  }
+    
+  return g_define_type_id__volatile;
+}
+
+GType
+ev_annotation_text_icon_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+ 
+  if (g_once_init_enter (&g_define_type_id__volatile)) {
+    static const GEnumValue values[] = {
+      { EV_ANNOTATION_TEXT_ICON_NOTE, "EV_ANNOTATION_TEXT_ICON_NOTE", "note" },
+      { EV_ANNOTATION_TEXT_ICON_COMMENT, "EV_ANNOTATION_TEXT_ICON_COMMENT", "comment" },
+      { EV_ANNOTATION_TEXT_ICON_KEY, "EV_ANNOTATION_TEXT_ICON_KEY", "key" },
+      { EV_ANNOTATION_TEXT_ICON_HELP, "EV_ANNOTATION_TEXT_ICON_HELP", "help" },
+      { EV_ANNOTATION_TEXT_ICON_NEW_PARAGRAPH, "EV_ANNOTATION_TEXT_ICON_NEW_PARAGRAPH", "new-paragraph" },
+      { EV_ANNOTATION_TEXT_ICON_PARAGRAPH, "EV_ANNOTATION_TEXT_ICON_PARAGRAPH", "paragraph" },
+      { EV_ANNOTATION_TEXT_ICON_INSERT, "EV_ANNOTATION_TEXT_ICON_INSERT", "insert" },
+      { EV_ANNOTATION_TEXT_ICON_CROSS, "EV_ANNOTATION_TEXT_ICON_CROSS", "cross" },
+      { EV_ANNOTATION_TEXT_ICON_CIRCLE, "EV_ANNOTATION_TEXT_ICON_CIRCLE", "circle" },
+      { EV_ANNOTATION_TEXT_ICON_UNKNOWN, "EV_ANNOTATION_TEXT_ICON_UNKNOWN", "unknown" },
+      { 0, NULL, NULL }
+    };
+    GType g_define_type_id = \
+       g_enum_register_static (g_intern_static_string ("EvAnnotationTextIcon"), values);
+      
+    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+  }
+    
+  return g_define_type_id__volatile;
+}
+
+/* enumerations from "ev-document-annotations.h" */
+#include "ev-document-annotations.h"
+GType
+ev_annotations_save_mask_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+ 
+  if (g_once_init_enter (&g_define_type_id__volatile)) {
+    static const GFlagsValue values[] = {
+      { EV_ANNOTATIONS_SAVE_NONE, "EV_ANNOTATIONS_SAVE_NONE", "none" },
+      { EV_ANNOTATIONS_SAVE_CONTENTS, "EV_ANNOTATIONS_SAVE_CONTENTS", "contents" },
+      { EV_ANNOTATIONS_SAVE_COLOR, "EV_ANNOTATIONS_SAVE_COLOR", "color" },
+      { EV_ANNOTATIONS_SAVE_LABEL, "EV_ANNOTATIONS_SAVE_LABEL", "label" },
+      { EV_ANNOTATIONS_SAVE_OPACITY, "EV_ANNOTATIONS_SAVE_OPACITY", "opacity" },
+      { EV_ANNOTATIONS_SAVE_POPUP_RECT, "EV_ANNOTATIONS_SAVE_POPUP_RECT", "popup-rect" },
+      { EV_ANNOTATIONS_SAVE_POPUP_IS_OPEN, "EV_ANNOTATIONS_SAVE_POPUP_IS_OPEN", "popup-is-open" },
+      { EV_ANNOTATIONS_SAVE_TEXT_IS_OPEN, "EV_ANNOTATIONS_SAVE_TEXT_IS_OPEN", "text-is-open" },
+      { EV_ANNOTATIONS_SAVE_TEXT_ICON, "EV_ANNOTATIONS_SAVE_TEXT_ICON", "text-icon" },
+      { EV_ANNOTATIONS_SAVE_ATTACHMENT, "EV_ANNOTATIONS_SAVE_ATTACHMENT", "attachment" },
+      { EV_ANNOTATIONS_SAVE_ALL, "EV_ANNOTATIONS_SAVE_ALL", "all" },
+      { 0, NULL, NULL }
+    };
+    GType g_define_type_id = \
+       g_flags_register_static (g_intern_static_string ("EvAnnotationsSaveMask"), values);
+      
+    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+  }
+    
+  return g_define_type_id__volatile;
+}
+
 /* enumerations from "ev-document.h" */
 #include "ev-document.h"
 GType
@@ -223,6 +305,7 @@ ev_compression_type_get_type (void)
       { EV_COMPRESSION_NONE, "EV_COMPRESSION_NONE", "none" },
       { EV_COMPRESSION_BZIP2, "EV_COMPRESSION_BZIP2", "bzip2" },
       { EV_COMPRESSION_GZIP, "EV_COMPRESSION_GZIP", "gzip" },
+      { EV_COMPRESSION_LZMA, "EV_COMPRESSION_LZMA", "lzma" },
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
@@ -312,6 +395,7 @@ ev_link_action_type_get_type (void)
       { EV_LINK_ACTION_TYPE_EXTERNAL_URI, "EV_LINK_ACTION_TYPE_EXTERNAL_URI", "external-uri" },
       { EV_LINK_ACTION_TYPE_LAUNCH, "EV_LINK_ACTION_TYPE_LAUNCH", "launch" },
       { EV_LINK_ACTION_TYPE_NAMED, "EV_LINK_ACTION_TYPE_NAMED", "named" },
+      { EV_LINK_ACTION_TYPE_LAYERS_STATE, "EV_LINK_ACTION_TYPE_LAYERS_STATE", "layers-state" },
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
