@@ -110,6 +110,9 @@ typedef struct _EvHeightToPageCache {
 struct _EvView {
 	GtkLayout layout;
 
+	/* Container */
+	GList *children;
+
 	EvDocument *document;
 
 	/* Find */
